local table = require( 'table' )
local os = require( 'os' )

local srcdir = os.getenv('srcdir') or '.'

local ea_db = table.concat( { srcdir, 'tests', 'data', 'annulus.rdb'}, '/' )

local intrinsic = require( 'saotrace.raygen.mock_intrinsics' )
local utils = require( 'saotrace.raygen.ea.utils.create_from_db' )
local va = require('validate.args')
local validate = va.validate


describe( "create_from_db utils", function () 

             before_each( function ()

                   getmetatable( require('saotrace.config') ).reset()
                   va.reset()
                   va.opts{ check_spec = true,
                            error_on_bad_spec = true,
                   }
                   intrinsic.stash = {}
             end)


             it( "test 1", function ()

                local nmatch = utils.create_from_db{ file = ea_db,
                                                     match = { shell = 3 },
                                                     type = 'annulus'
                }

                assert.same( 1, nmatch )
                assert.same( 10, intrinsic.stash[1][1].opts.ro )

             end)

             it( "test_2", function ( )

                local nmatch = utils.create_from_db{ file = ea_db,
                                                     match = function( rec )
                                                        return rec.shell < 3
                                                     end,
                                                     type = 'annulus'
                }

                assert.same(2 , nmatch )
                assert.same( 10, intrinsic.stash[1][1].opts.ro )
                assert.same(  8, intrinsic.stash[2][1].opts.ro )

             end)

             it( "test_colmap_circle", function ( )

                local nmatch = utils.create_from_db{ file = ea_db,
                                                     match = function( rec )
                                                        return rec.shell < 3
                                                     end,
                                                     col = { r = 'ro' },
                                                     type = 'circle'
                }

                assert.same(2 , nmatch )
                assert.same( 10, intrinsic.stash[1][1].opts.r )
                assert.same(  8, intrinsic.stash[2][1].opts.r )

             end)

             it( "test_colmap_point", function( )

                local nmatch = utils.create_from_db{ file = ea_db,
                                                     match = function( rec )
                                                        return rec.shell < 3
                                                     end,
                                                     type = 'pinhole'
                }

                assert.same(2 , nmatch )
                assert.same( 0, intrinsic.stash[1][1].opts.x )
                assert.same( 2, intrinsic.stash[2][1].opts.y )

             end)

end)
